@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,178 +14,189 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import sys
 import os
 from os import path
 import re
 import platform
 from calculate.lib.datavars import (Variable, SimpleDataVars, ReadonlyVariable,
-            VariableError)
+                                    VariableError, VariableInterface)
 
-from calculate.lib.utils.portage import isPkgInstalled, searchProfile, \
-    RepositorySubstituting
+from calculate.lib.utils.portage import (isPkgInstalled, searchProfile,
+                                         RepositorySubstituting)
 from calculate.lib.utils.files import readFile, pathJoin
 from calculate.lib.configparser import ConfigParser
 import env
 
-class Linux:
-    dictLinuxName = {"CLD":"Calculate Linux Desktop",
-                     "CLDX":"Calculate Linux Desktop",
-                     "CLDG":"Calculate Linux Desktop",
-                     "CDS":"Calculate Directory Server",
-                     "CLS":"Calculate Linux Scratch",
-                     "CSS":"Calculate Scratch Server",
-                     "CMC":"Calculate Media Center",
-                     "Gentoo":"Gentoo"}
+_ = lambda x: x
+from calculate.lib.cl_lang import setLocalTranslate
 
-    dictLinuxSubName = {"CLD":"KDE", "CLDX":"XFCE", "CLDG":"GNOME"}
+setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-    dictNameSystem = {'CDS':'server',
-                      'CLD':'desktop',
-                      'CLDG':'desktop',
-                      'CLDX':'desktop',
-                      'CLS':'desktop',
-                      'CMC':'desktop',
-                      'CSS':'server'}
 
-    def getFullNameByShort(self,shortname):
+class Linux(VariableInterface):
+    dictLinuxName = {"CLD": "Calculate Linux Desktop",
+                     "CLDX": "Calculate Linux Desktop",
+                     "CLDG": "Calculate Linux Desktop",
+                     "CDS": "Calculate Directory Server",
+                     "CLS": "Calculate Linux Scratch",
+                     "CSS": "Calculate Scratch Server",
+                     "CMC": "Calculate Media Center",
+                     "Gentoo": "Gentoo"}
+
+    dictLinuxSubName = {"CLD": "KDE", "CLDX": "XFCE", "CLDG": "GNOME"}
+
+    dictNameSystem = {'CDS': 'server',
+                      'CLD': 'desktop',
+                      'CLDG': 'desktop',
+                      'CLDX': 'desktop',
+                      'CLS': 'desktop',
+                      'CMC': 'desktop',
+                      'CSS': 'server'}
+
+    def getFullNameByShort(self, shortname):
         """Get full distributive name by short name"""
-        subname = self.dictLinuxSubName.get(shortname,'')
-        if subname: subname = " %s"%subname
-        return "%s%s"%(self.dictLinuxName.get(shortname,''),subname)
+        subname = self.dictLinuxSubName.get(shortname, '')
+        if subname:
+            subname = " %s" % subname
+        return "%s%s" % (self.dictLinuxName.get(shortname, ''), subname)
 
-    def getShortnameByMakeprofile(self,systemroot):
+    def getShortnameByMakeprofile(self, systemroot):
         """Get shortname by symlink of make.profile"""
         makeprofile = self.Get('cl_make_profile')
         if path.exists(makeprofile):
             link = os.readlink(makeprofile)
-            reMakeProfileLink = re.compile('/calculate/(desktop|server)/(%s)/'%
-                        "|".join(self.dictLinuxName.keys()),re.S)
-            shortnameSearch = reMakeProfileLink.search(link)
-            if shortnameSearch:
-                return shortnameSearch.groups()[1]
+            re_make_profile_link = re.compile(
+                '/calculate/(desktop|server)/(%s)/' %
+                "|".join(self.dictLinuxName.keys()), re.S)
+            shortname_search = re_make_profile_link.search(link)
+            if shortname_search:
+                return shortname_search.groups()[1]
         return None
 
-    def getShortnameByIni(self,systemroot):
+    def getShortnameByIni(self, systemroot):
         """Get shortname by calculate.ini file"""
-        inifile = path.join(systemroot,'etc/calculate/calculate.ini')
+        inifile = path.join(systemroot, 'etc/calculate/calculate.ini')
         if path.exists(inifile):
-            FD = open(inifile)
-            data = FD.readlines()
-            FD.close()
-            shortNameList = filter(lambda y:y,
-                                   map(lambda x:\
-                                       len(x.split("="))==2 and\
-                                       x.split("=")[0]=="calculate" and\
-                                       x.split("=")[1].strip(), data))
-            if shortNameList:
-                return shortNameList[0]
+            with open(inifile) as f:
+                data = f.readlins()
+            short_name_list = filter(
+                None, map(lambda x: (len(x.split("=")) == 2 and
+                                     x.split("=")[0] == "calculate" and
+                                     x.split("=")[1].strip()), data))
+            if short_name_list:
+                return short_name_list[0]
 
-    def detectOtherShortname(self,systemroot):
+    def detectOtherShortname(self, systemroot):
         """Detect other system. Now only Gentoo."""
-        gentooFile = path.join(systemroot, "etc/gentoo-release")
-        if path.exists(gentooFile):
+        gentoo_file = path.join(systemroot, "etc/gentoo-release")
+        if path.exists(gentoo_file):
             return "Gentoo"
         if all(map(lambda x: path.lexists(path.join(systemroot, x)),
                    ['bin', 'var', 'lib', 'etc'])):
             return "Linux"
         return None
 
-    def getVersionFromOverlay(self,systemroot):
+    def getVersionFromOverlay(self, systemroot):
         """
         Get version from overlay calculate-release
         """
-        overlayPath = 'var/lib/layman/calculate'
-        releaseFile = 'profiles/calculate-release'
-        return readFile(path.join(systemroot, overlayPath, releaseFile))
+        overlay_path = 'var/lib/layman/calculate'
+        release_file = 'profiles/calculate-release'
+        return readFile(path.join(systemroot, overlay_path, release_file))
 
-    def getVersionFromMetapackage(self,systemroot,shortname):
+    def getVersionFromMetapackage(self, systemroot, shortname):
         """Get version from meta package"""
         for pkg in ("app-misc/calculate-meta", "app-misc/%s-meta" % shortname):
-            calcMeta = isPkgInstalled(pkg, systemroot)
-            if calcMeta:
-                return calcMeta[0]['PV']
+            calc_meta = isPkgInstalled(pkg, systemroot)
+            if calc_meta:
+                return calc_meta[0]['PV']
         return None
 
     def getVersionFromCalculateIni(self, systemroot):
         """Get version from calculate ini"""
         pathname = path.join(systemroot,
-                      'etc/calculate/calculate.ini')
+                             'etc/calculate/calculate.ini')
         if path.exists(pathname):
-            FD = open(pathname)
-            data = FD.readlines()
-            FD.close()
-            verList = filter(lambda y:y,
-                                   map(lambda x:\
-                                       len(x.split("="))==2 and\
-                                       x.split("=")[0]=="linuxver" and\
-                                       x.split("=")[1].strip(), data))
-            if verList:
-                reVer=re.compile("^(\d+\.)*\d$",re.S)
-                reRes = filter(reVer.search,verList)
-                if reRes:
-                    return reRes[0]
+            with open(pathname) as f:
+                data = f.readlines()
+            ver_list = filter(
+                None, map(lambda x:
+                          (len(x.split("=")) == 2 and
+                           x.split("=")[0] == "linuxver" and
+                           x.split("=")[1].strip()), data))
+            if ver_list:
+                re_ver = re.compile("^(\d+\.)*\d$", re.S)
+                re_res = filter(re_ver.search, ver_list)
+                if re_res:
+                    return re_res[0]
 
-    def getVersionFromGentooFiles(self,systemroot):
+    def getVersionFromGentooFiles(self, systemroot):
         """Get version from gentoo files"""
-        gentooFile = path.join(systemroot,"etc/gentoo-release")
-        reVer=re.compile("^(\d+\.)*\d+$",re.S)
-        if path.exists(gentooFile):
-            gentooLink = self.Get('cl_make_profile')
-            if path.islink(gentooLink):
-                vers = filter(reVer.search,
-                              os.readlink(gentooLink).split('/'))
+        gentoo_file = path.join(systemroot, "etc/gentoo-release")
+        re_ver = re.compile("^(\d+\.)*\d+$", re.S)
+        if path.exists(gentoo_file):
+            gentoo_link = self.Get('cl_make_profile')
+            if path.islink(gentoo_link):
+                vers = filter(re_ver.search,
+                              os.readlink(gentoo_link).split('/'))
                 if vers:
                     return vers[-1]
 
     def getVersionFromUname(self):
         """Get version from uname"""
-        reVer=re.search("^(\d+\.)*\d",platform.release(),re.S)
-        if reVer:
-            return reVer.group()
+        re_ver = re.search("^(\d+\.)*\d", platform.release(), re.S)
+        if re_ver:
+            return re_ver.group()
 
-class VariableOsLinuxShortname(Variable,Linux):
+
+class VariableOsLinuxShortname(Variable, Linux):
     """
     Short system name (Example:CLD)
     """
     systemRoot = "/"
 
     def get(self):
-        return self.getShortnameByMakeprofile(self.systemRoot) or \
-               self.getShortnameByIni(self.systemRoot) or \
-               self.detectOtherShortname(self.systemRoot) or \
-               "Linux"
+        return (self.getShortnameByMakeprofile(self.systemRoot) or
+                self.getShortnameByIni(self.systemRoot) or
+                self.detectOtherShortname(self.systemRoot) or
+                "Linux")
 
-class VariableOsLinuxName(Variable,Linux):
+
+class VariableOsLinuxName(Variable, Linux):
     """
     Full system name
     """
     source_variable = "os_linux_shortname"
 
     def get(self):
-        linuxShortName = self.Get(self.source_variable)
-        return self.dictLinuxName.get(linuxShortName,"Linux")
+        linux_short_name = self.Get(self.source_variable)
+        return self.dictLinuxName.get(linux_short_name, "Linux")
 
-class VariableOsLinuxSubname(Variable,Linux):
+
+class VariableOsLinuxSubname(Variable, Linux):
     """
     Subname of linux (KDE, GNOME, XFCE and etc)
     """
     source_variable = "os_linux_shortname"
-    
-    def get(self):
-        linuxShortName = self.Get(self.source_variable)
-        return self.dictLinuxSubName.get(linuxShortName,"")
 
-class VariableOsLinuxSystem(Variable,Linux):
+    def get(self):
+        linux_short_name = self.Get(self.source_variable)
+        return self.dictLinuxSubName.get(linux_short_name, "")
+
+
+class VariableOsLinuxSystem(Variable, Linux):
     """
     System of linux (desktop or server)
     """
     source_variable = "os_linux_shortname"
 
     def get(self):
-        shortName = self.Get(self.source_variable)
-        return self.dictNameSystem.get(shortName,"")
+        short_name = self.Get(self.source_variable)
+        return self.dictNameSystem.get(short_name, "")
 
-class VariableOsLinuxVer(Variable,Linux):
+
+class VariableOsLinuxVer(Variable, Linux):
     """
     Version of system (get by metapackage,calculate.ini,gentoo files or 0)
     """
@@ -193,20 +204,22 @@ class VariableOsLinuxVer(Variable,Linux):
 
     def get(self):
         """Get system version"""
-        linuxShortName = self.Get("os_linux_shortname")
-        return self.getVersionFromOverlay(self.systemRoot) or \
-            self.getVersionFromMetapackage(self.systemRoot,
-                                              linuxShortName) or \
-            self.getVersionFromCalculateIni(self.systemRoot) or \
-            self.getVersionFromGentooFiles(self.systemRoot) or \
-            self.getVersionFromUname() or "0"
+        linux_short_name = self.Get("os_linux_shortname")
+        return (self.getVersionFromOverlay(self.systemRoot) or
+                self.getVersionFromMetapackage(
+                    self.systemRoot, linux_short_name) or
+                self.getVersionFromCalculateIni(self.systemRoot) or
+                self.getVersionFromGentooFiles(self.systemRoot) or
+                self.getVersionFromUname() or "0")
 
-class VariableOsLinuxBuild(Variable,Linux):
+
+class VariableOsLinuxBuild(Variable, Linux):
     """
     Build of system
     """
 
-class VariableOsLinuxFilesnum(Variable,Linux):
+
+class VariableOsLinuxFilesnum(Variable, Linux):
     systemRoot = "/"
 
     def get(self):
@@ -215,9 +228,10 @@ class VariableOsLinuxFilesnum(Variable,Linux):
         operation. This value is already count by calculate-builder and
         is placed in calculate3.env"""
         return str(0)
-        #return str(countFiles(self.systemRoot))
+        # return str(countFiles(self.systemRoot))
 
-class VariableOsLinuxFiles(Variable,Linux):
+
+class VariableOsLinuxFiles(Variable, Linux):
     systemRoot = "/"
 
     def get(self):
@@ -225,7 +239,7 @@ class VariableOsLinuxFiles(Variable,Linux):
         operation. This value is already count by calculate-builder and
         is placed in calculate.env"""
         return self.Get('os_linux_filesnum')
-        #return str(countFiles(self.systemRoot))
+        # return str(countFiles(self.systemRoot))
 
 
 class VariableOsLinuxPkglist(Variable):
@@ -238,7 +252,10 @@ class VariableOsLinuxPkglist(Variable):
             config = ConfigParser(strict=False)
             config.read(fn, encoding="utf-8")
             value = SimpleDataVars.unserialize("string",
-               config.get('main', 'os_linux_shortname',raw=True, fallback=''))
+                                               config.get('main',
+                                                          'os_linux_shortname',
+                                                          raw=True,
+                                                          fallback=''))
             yield value.encode('utf-8')
         yield "base"
 
@@ -255,6 +272,7 @@ class VariableClProfileSystem(ReadonlyVariable):
     """
     Профиль системы (симлинк /etc/make.profile')
     """
+
     def get(self):
         try:
             make_profile = self.Get('cl_make_profile')
