@@ -217,7 +217,16 @@ class Locale(object):
             'keymap': 'uk',
             'dumpkeys_charset': '',
             'consolefont': 'LatArCyrHeb-16',
-            'xkblayout': 'us,gb',
+            'xkblayout': 'gb',
+            'language': 'en',
+        },
+        'en_AU': {
+            'name': __('Australian'),
+            'locale': 'en_AU.UTF-8',
+            'keymap': 'us',
+            'dumpkeys_charset': '',
+            'consolefont': 'LatArCyrHeb-16',
+            'xkblayout': 'us',
             'language': 'en',
         },
         'en_US': {
