@@ -20,9 +20,10 @@ import platform
 import re
 from calculate.lib.utils.dracut import Dracut
 from calculate.lib.datavars import Variable, ReadonlyVariable
-from calculate.lib.utils.files import readFile, process, listDirectory, isMount
+from calculate.lib.utils.files import (readFile, process, listDirectory,
+                                       isMount, pathJoin)
 from calculate.lib.utils.device import getUdevDeviceInfo, loadEfiVars
-from calculate.lib.utils.common import getKernelUid
+from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine
 
 
 class VariableOsArchMachine(ReadonlyVariable):
@@ -115,6 +116,7 @@ class RootType(object):
     """
     Типы загруженной системы
     """
+
     class Value(object):
         HDD = "hdd"
         LiveCD = "livecd"
@@ -127,6 +129,7 @@ class RootType(object):
     HDD = (Value.HDD,)
     LiveCD = (Value.LiveCD,)
     USB_HDD = (Value.USB_HDD,)
+    HDDs = (Value.HDD, Value.USB_HDD,)
     LiveFlash = (Value.LiveFlash,)
     IsoScanGrub = (Value.IsoScanGrub,)
     IsoScanFlash = (Value.IsoScanFlash,)
@@ -154,6 +157,27 @@ class VariableOsRootType(ReadonlyVariable):
         return "hdd"
 
 
+class VariableClIsoscanPath(ReadonlyVariable):
+    """
+    Образ с которого загружена система
+    """
+
+    def get(self):
+        return getValueFromCmdLine("iso-scan/filename", 0) or ""
+
+
+class VariableClIsoscanFullpath(ReadonlyVariable):
+    """
+    Путь в системе до образа с которого загружена система
+    """
+
+    def get(self):
+        isoscan_path = self.Get('cl_isoscan_path')
+        if isoscan_path:
+            return pathJoin(Dracut.IsoScanPath, isoscan_path)
+        return ""
+
+
 class VariableOsRootTypeExt(ReadonlyVariable):
     """
     Расширенный тип загруженной системы
@@ -173,8 +197,11 @@ class VariableOsRootTypeExt(ReadonlyVariable):
 
             if "/dev/ram" in root_dev:
                 record = readFile('/proc/cmdline').strip()
-                if "iso-scan/filename" in record:
-                    if path.exists(path.join(Dracut.IsoScanPath, "grub.cfg")):
+                if self.Get('cl_isoscan_path'):
+                    grub_cfg = path.join(
+                        path.dirname(self.Get('cl_isoscan_fullpath')),
+                        "grub.cfg")
+                    if path.exists(grub_cfg):
                         return RootType.Value.IsoScanGrub
                     else:
                         return RootType.Value.IsoScanFlash
@@ -272,6 +299,7 @@ class VariableClSystemBootSet(ReadonlyVariable):
         else:
             return "off"
 
+
 class VariableClLivePath(Variable):
     """
     Путь до образов из которых будет формировать live меню для grub
